==> p2-maven-plugin-1.2.0-sources.jar: org/reficio/p2/resolver/maven/impl/AetherResolver.java <==
package org.reficio.p2.resolver.maven.impl;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class AetherResolver
  extends java.lang.Object  implements
    org.reficio.p2.resolver.maven.ArtifactResolver,    groovy.lang.GroovyObject {
public AetherResolver
(java.lang.Object repositorySystem, java.lang.Object repositorySystemSession, java.util.List<?> repos) {
super ();
}
public AetherResolver
(java.lang.Object repositorySystem, java.lang.Object repositorySystemSession, java.util.List<?> remoteRepositories, java.lang.String scope) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.lang.String getDEFAULT_SCOPE() { return (java.lang.String)null;}
public final  java.lang.Object getRepositorySystem() { return null;}
public final  java.lang.Object getRepositorySystemSession() { return null;}
public final  java.util.List<?> getRemoteRepositories() { return (java.util.List)null;}
public final  java.lang.String getScope() { return (java.lang.String)null;}
public final  org.reficio.p2.resolver.maven.impl.facade.AetherFacade getAether() { return (org.reficio.p2.resolver.maven.impl.facade.AetherFacade)null;}
@java.lang.Override() public  org.reficio.p2.resolver.maven.ArtifactResolutionResult resolve(org.reficio.p2.resolver.maven.ArtifactResolutionRequest request) { return (org.reficio.p2.resolver.maven.ArtifactResolutionResult)null;}
}

==> p2-maven-plugin-1.7.0-sources.jar: org/reficio/p2/resolver/maven/impl/AetherResolver.java <==
package org.reficio.p2.resolver.maven.impl;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;

@edu.umd.cs.findbugs.annotations.SuppressFBWarnings(value="SE_NO_SERIALVERSIONID") public class AetherResolver
  extends java.lang.Object  implements
    org.reficio.p2.resolver.maven.ArtifactResolver,    groovy.lang.GroovyObject {
;
public AetherResolver
(java.lang.Object repositorySystem, java.lang.Object repositorySystemSession, java.util.List<?> repos) {
super ();
}
public AetherResolver
(java.lang.Object repositorySystem, java.lang.Object repositorySystemSession, java.util.List<?> remoteRepositories, java.lang.String scope) {}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.lang.String getDEFAULT_SCOPE() { return (java.lang.String)null;}
public final  java.lang.Object getRepositorySystem() { return null;}
public final  java.lang.Object getRepositorySystemSession() { return null;}
public final  java.util.List<?> getRemoteRepositories() { return (java.util.List<?>)null;}
public final  java.lang.String getScope() { return (java.lang.String)null;}
public final  org.reficio.p2.resolver.maven.impl.facade.AetherFacade getAether() { return (org.reficio.p2.resolver.maven.impl.facade.AetherFacade)null;}
@java.lang.Override() public  org.reficio.p2.resolver.maven.ArtifactResolutionResult resolve(org.reficio.p2.resolver.maven.ArtifactResolutionRequest request) { return (org.reficio.p2.resolver.maven.ArtifactResolutionResult)null;}
}
